'''
Description: A script to clean a csv (of the standard state general election 
results csv format) to a usable form for the data visualization
Author: Tiffany Xiao
Date Last Edited: 11/24/2019 
'''
import pandas as pd
import numpy as np 

def main():
    '''Function to clean general csv file '''
    # get file
    filename_in = input("What is the filename (must be in data folder)? (Testing: 20161108__ny__general.csv) \n")
    filename = "data/"+filename_in

    # read csv into dataframe
    df = pd.read_csv(filename)
    # drop NaN columns
    df = df.dropna(axis=1, how='all')
    # drop duplicate rows
    df.drop_duplicates(keep=False, inplace=True)

    # calculate total percentage for each office
    county_office = df.groupby(['county','office','party']).agg({'votes':'sum'})
    county_pcts = county_office.groupby(['county','office']).apply(lambda x: 100 * x / float(x.sum()))
    county_pcts = county_pcts.add_suffix('_perct').reset_index()

    # pivot to party votes
    pivot_df = pd.pivot_table(county_pcts,values='votes_perct',index=['county','office'],columns='party').reset_index()
    pivot_df['state'] = 'New York'
    pivot_df['sum'] = pivot_df.drop(['county','office','DEM','REP'], axis=1).sum(axis=1)

    # write to csv
    filename_out = "cleaned_"+filename_in
    export_csv = pivot_df.to_csv(filename_out)

if __name__ == "__main__":
    main()
